@@ -7,8 +7,8 @@ from ..models.config import NotifyConfig
 class NotifyConfigAdmin(SingletonModelAdmin):
     fieldsets = (
         (None, {
-            'fields': ('periodic', 'is_email_enabled', 'is_sms_enabled', 'is_push_enabled', 'is_telegram_enabled',
-                       'is_viber_enabled')
+            'fields': ('periodic', 'is_email_enabled', 'is_sms_enabled', 'is_call_enabled', 'is_push_enabled',
+                       'is_telegram_enabled', 'is_viber_enabled')
         }),
         ('Почта', {
             'fields': ('email_max_day_limit', 'email_max_hour_limit', 'email_malling')
@@ -20,8 +20,10 @@ class NotifyConfigAdmin(SingletonModelAdmin):
             'fields': ('call_url_type', 'call_api_id', 'call_login', 'call_password')
         }),
         ('Telegram', {
-            'fields': ('telegram_api_key', 'telegram_bot_name', 'telegram_welcome_text', 'telegram_help_text', 'telegram_bad_command_text',
-                       'telegram_success_added_text', 'telegram_failed_added_text')
+            'fields': ('telegram_api_key', 'telegram_bot_name', 'telegram_welcome_text', 'telegram_help_text',
+                       'telegram_bad_command_text', 'telegram_success_added_text', 'telegram_failed_added_text',
+                       'telegram_parse_mode', 'telegram_disable_notification', 'telegram_disable_web_page_preview',
+                       'telegram_allow_sending_without_reply', 'telegram_timeout')
         }),
         ('Viber', {
             'fields': ('viber_api_key', 'viber_bot_name', 'viber_success_added_text',
