@@ -6,16 +6,15 @@ from .config import NotifyConfig
 
 
 class SMTPAccount(models.Model):
-    host = models.CharField(default='smtp.yandex.ru', max_length=255, verbose_name='Хост')
-    port = models.IntegerField(default=587, verbose_name='Порт')
-    is_use_tls = models.BooleanField(default=True, verbose_name='Использовать TLS?')
-    is_use_ssl = models.BooleanField(default=False, verbose_name='Использовать SSL?')
+    host = models.CharField(default='smtp.yandex.com', max_length=255, verbose_name='Хост')
+    port = models.IntegerField(default=465, verbose_name='Порт')
+    is_use_tls = models.BooleanField(default=False, verbose_name='Использовать TLS?')
+    is_use_ssl = models.BooleanField(default=True, verbose_name='Использовать SSL?')
     sender = models.EmailField(max_length=255, blank=True, default='', verbose_name='Отправитель')
     username = models.CharField(max_length=255, blank=True, default='', verbose_name='Имя пользователя')
     password = models.CharField(max_length=255, blank=True, default='', verbose_name='Пароль пользователя')
     timeout = models.IntegerField(default=5000, verbose_name='Таймаут (сек.)')
     category = models.ForeignKey(NotifyCategory, on_delete=models.CASCADE, related_name='accounts', verbose_name='Тип')
-
     is_active = models.BooleanField(default=True, verbose_name='Включить аккаунт')
 
     email_hour_used_times = models.IntegerField(default=0, verbose_name='Количество использований в час')
