@@ -14,7 +14,6 @@ CALL_URL_TYPE = 0
 CALL_API_ID = 1234567890
 CALL_LOGIN = ''
 CALL_PASSWORD = ''
-CALL_FROM = ''
 # TELEGRAM
 TELEGRAM_API_KEY = '000000000:AAAAAAAAAA-AAAAAAAA-_AAAAAAAAAAAAAA'
 TELEGRAM_BOT_NAME = 'MySuperBot'
@@ -23,6 +22,11 @@ TELEGRAM_HELP_TEXT = '/set !help for HELP'
 TELEGRAM_BAD_COMMAND_TEXT = 'Incorrect command format'
 TELEGRAM_SUCCESS_ADDED_TEXT = 'Success'
 TELEGRAM_FAILED_ADDED_TEXT = 'Failed'
+TELEGRAM_PARSE_MODE = None
+TELEGRAM_DISABLE_NOTIFICATION = False
+TELEGRAM_DISABLE_PAGE_PREVIEW = False
+TELEGRAM_SENDING_WITHOUT_REPLY = False
+TELEGRAM_TIMEOUT = None
 # VIBER
 VIBER_API_KEY = '000000000:AAAAAAAAAA-AAAAAAAA-_AAAAAAAAAAAAAA'
 VIBER_BOT_NAME = 'MySuperViberBot'
@@ -33,3 +37,6 @@ VIBER_TEXT_FOR_NEW_SUB = 'HI!'
 # SETTINGS
 EMAIL_MALLING = 1
 GARPIX_NOTIFY_MIXIN = 'garpix_notify.mixins.notify_mixin.NotifyMixin'
+NOTIFY_USER_WANT_MESSAGE_CHECK = None
+NOTIFY_CALL_CODE_CHECK = None
+GARPIX_NOTIFY_CELERY_SETTINGS = 'app.celery.app'
